@@ -6,6 +6,8 @@ The magic relies on your view being class-based and having a build_object
 method, like the BuildableDetailView included in this app.
 """
 from django.db import models
+from django.db import transaction
+from django.contrib.contenttypes.models import ContentType
 
 
 class BuildableModel(models.Model):
@@ -149,13 +151,23 @@ class AutoPublishingBuildableModel(BuildableModel):
                 # If it's remaining unpublished...
                 else:
                     action = None
-            # Now, no matter what, save it normally
-            super(AutoPublishingBuildableModel, self).save(*args, **kwargs)
+            # Now, no matter what, save it normally inside of a dedicated
+            # database transaction so that we are sure that the save will
+            # be complete before we trigger any task
+            if hasattr(transaction, 'atomic'):
+                # For >= Django 1.6
+                transaction_manager = getattr(transaction, 'atomic')
+            else:
+                # For < Django 1.6
+                transaction_manager = getattr(transaction, 'commit_on_success')
+            with transaction_manager():
+                super(AutoPublishingBuildableModel, self).save(*args, **kwargs)
             # Finally, depending on the action, fire off a task
+            ct = ContentType.objects.get_for_model(self.__class__)
             if action == 'publish':
-                tasks.publish_object.delay(self)
+                tasks.publish_object.delay(ct.pk, self.pk)
             elif action == 'unpublish':
-                tasks.unpublish_object.delay(self)
+                tasks.unpublish_object.delay(ct.pk, self.pk)
 
     def delete(self, *args, **kwargs):
         """
@@ -168,10 +180,9 @@ class AutoPublishingBuildableModel(BuildableModel):
         unpublish = kwargs.pop('unpublish', True)
         # Delete it from the database
         super(AutoPublishingBuildableModel, self).delete(*args, **kwargs)
-        if not unpublish:
-            pass
-        else:
-            tasks.unpublish_object.delay(self)
+        if unpublish:
+            ct = ContentType.objects.get_for_model(self.__class__)
+            tasks.unpublish_object.delay(ct.pk, self.pk)
 
     class Meta:
         abstract = True
